@@ -1,7 +1,8 @@
 -- Lua script example
 -- Lenny Palozzi
 
-CL_Display:set_videomode(640, 480, 16)
+CL_Display:set_videomode(640, 480, 16,0)
+CL_Display:clear_display()
 
 msg = call(format, {"Video Mode: %dx%d", CL_Display:get_width(), CL_Display:get_height()} )
 print(msg)
