@@ -1,6 +1,6 @@
 -- Example 3
 
-CL_Display:set_videomode(320, 200, 16)
+CL_Display:set_videomode(320, 200, 16,0)
 
 my_canvas = CL_Canvas:new(320, 200)
 my_cliprect = CL_ClipRect:new(20, 20, 280, 160)
