@@ -39,7 +39,7 @@
 \**********************************************************************/
 
 //static const char
-//*cvs_id = "$Id: appconf.cpp,v 1.3 2000/04/28 23:55:32 mbn Exp $";
+//*cvs_id = "$Id: appconf.cpp,v 1.5 2001/07/03 09:02:01 sphair Exp $";
 
 // ============================================================================
 // headers, constants, private declarations
@@ -69,13 +69,13 @@
 #include  <fcntl.h>
 #include  <sys/types.h>
 #include  <iostream>
-#include  <fstream.h>
-#include  <string.h>
+#include  <fstream>
+#include  <cstring>
 #include  <cctype>
-#include  <stdio.h>
-#include  <stdlib.h>
-#include  <stdarg.h>
-#include  <assert.h>
+#include  <cstdio>
+#include  <cstdlib>
+#include  <cstdarg>
+#include  <cassert>
 
 // our headers
 #include  "appconf.h"
@@ -91,7 +91,7 @@
 #	define	_(x)	(x)
 #endif
 
-using namespace std;
+//using namespace std;
 
 #ifndef   __WXWIN__
 
@@ -166,7 +166,7 @@ inline size_t Min(size_t n1, size_t n2) { return n1 < n2 ? n1 : n2; }
 # define StrCmp(s1,s2)  strcmp((s1),(s2))
 #else
 # ifdef   __unix__
-    extern "C" int strcasecmp(const char *s1, const char *s2); // it's not ansi
+//strcasecmp is in string.h
 #   define  StrCmp(s1,s2)  strcasecmp((s1),(s2))
 # else
 #   ifdef _MSC_VER
@@ -1151,7 +1151,7 @@ Bool FileConfig::ConfigGroup::flush(std::ostream *ostr)
         if ( pName != NULL ) {
           *ostr << '[' << pName << ']';
           if ( pEntry->Comment() == NULL )
-            *ostr << endl;
+            *ostr << std::endl;
           delete [] pName;
         }
         //else: it's the top (default) group
@@ -1165,7 +1165,7 @@ Bool FileConfig::ConfigGroup::flush(std::ostream *ostr)
       }
       
       char *szFilteredValue = filterOut(pEntry->Value());
-      *ostr << pEntry->Name() << " = " << szFilteredValue << endl;
+      *ostr << pEntry->Name() << " = " << szFilteredValue << std::endl;
       delete [] szFilteredValue;
 
       pEntry->SetDirty(FALSE);
@@ -1222,10 +1222,10 @@ FileConfig::FileConfig(const char *szFileName, Bool bLocalOnly, Bool bUseSubDir)
   
   // read global (system wide) file
   // ------------------------------
-  ifstream inpStream;
+  std::ifstream inpStream;
   if ( !bLocalOnly ) {
     m_szFullFileName = GlobalConfigFile();
-    inpStream.open(m_szFullFileName, ios::in);
+    inpStream.open(m_szFullFileName, std::ios::in);
     if ( inpStream ) {
       m_bParsingLocal = FALSE;
       m_bOk = readStream(&inpStream);
@@ -1239,7 +1239,7 @@ FileConfig::FileConfig(const char *szFileName, Bool bLocalOnly, Bool bUseSubDir)
   // ------------------------
   m_szFullFileName = LocalConfigFile();
   if ( m_szFullFileName != NULL ) {
-    inpStream.open(m_szFullFileName, ios::in);
+    inpStream.open(m_szFullFileName, std::ios::in);
     if ( inpStream ) {
       m_bParsingLocal = TRUE;
       if ( readStream(&inpStream) ) {
@@ -1254,7 +1254,7 @@ FileConfig::FileConfig(const char *szFileName, Bool bLocalOnly, Bool bUseSubDir)
 }
 
 // ctor reads data from files
-FileConfig::FileConfig(istream *iStream)
+FileConfig::FileConfig(std::istream *iStream)
 {
   Init();
   
@@ -1279,7 +1279,7 @@ FileConfig::FileConfig(void)
 void
 FileConfig::readFile(const char *szFileName)
 {
-  ifstream inpStream;
+  std::ifstream inpStream;
 
   Init();
 
@@ -1287,7 +1287,7 @@ FileConfig::readFile(const char *szFileName)
    strcpy(m_szFileName, szFileName);
 
    m_szFullFileName = m_szFileName;
-   inpStream.open(m_szFullFileName, ios::in);
+   inpStream.open(m_szFullFileName, std::ios::in);
    if ( inpStream ) {
       m_bParsingLocal = TRUE;
       if ( readStream(&inpStream) ) {
@@ -1311,7 +1311,7 @@ FileConfig::~FileConfig()
   delete m_pRootGroup;
   
   if ( m_szFileName != NULL )
-     delete m_szFileName;
+     delete [] m_szFileName;
 }
 
 // ----------------------------------------------------------------------------
@@ -1400,7 +1400,7 @@ const char *FileConfig::LocalConfigFile() const
 // ----------------------------------------------------------------------------
 
 // parse the stream and create all groups and entries found in it
-Bool FileConfig::readStream(istream *istr, ConfigGroup *pRootGroup)
+Bool FileConfig::readStream(std::istream *istr, ConfigGroup *pRootGroup)
 {
   char szBuf[APPCONF_STRBUFLEN];
 
@@ -1669,7 +1669,7 @@ Bool FileConfig::flush(Bool bCurrentOnly)
   ConfigGroup *pRootGroup = bCurrentOnly ? m_pCurGroup : m_pRootGroup;
 
   if ( m_pRootGroup->IsDirty() ) {
-    fstream outStream(LocalConfigFile(), ios::out);
+    std::fstream outStream(LocalConfigFile(), std::ios::out);
 
     Bool bOk = pRootGroup->flush(&outStream);
     
