@@ -1,5 +1,5 @@
 /*
-	$Id: mutex_win32.h,v 1.1.1.1 2000/04/09 12:18:02 mbn Exp $
+	$Id: mutex_win32.h,v 1.4 2001/05/07 08:36:59 mbn Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -16,23 +16,14 @@
 #define header_mutex_win32
 
 #include "API/Core/System/mutex.h"
+#include "API/Core/System/cl_assert.h"
 #include <windows.h>
 
-class CL_Mutex_Win32 : public CL_Mutex
+class CL_Mutex_Generic
 {
 public:
-	CL_Mutex_Win32();
-	virtual ~CL_Mutex_Win32();
-
-	virtual void enter();
-	virtual void leave();
-
-	virtual void wait() { cl_assert(false); } // not implemented
-	virtual void notify() { cl_assert(false); } // not implemented
-	virtual void notify_all() { cl_assert(false); } // not implemented
-
-private:
 	CRITICAL_SECTION mutex;
+	HANDLE event;
 };
 
 #endif
\ No newline at end of file
