@@ -1,5 +1,5 @@
 /*
-	$Id: texture_gl.h,v 1.1.1.1 2000/04/09 12:18:02 mbn Exp $
+	$Id: texture_gl.h,v 1.4 2001/02/17 17:12:10 plasmoid Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -34,7 +34,8 @@ public:
 	virtual void reload(); 
 	virtual int get_width() const;
 	virtual int get_height() const;
-	virtual int get_no_textures() const;
+	virtual int get_num_textures() const;
+	virtual int get_num_frames() const;
 	virtual void flush(CL_DisplayCard *card = NULL);
 
 private:
@@ -45,4 +46,4 @@ private:
 	int num_textures;
 };
 
-#endif
\ No newline at end of file
+#endif
