@@ -1,5 +1,5 @@
 /*
-	$Id: displaycard_opengl_win32.h,v 1.1.1.1 2000/04/09 12:18:02 mbn Exp $
+	$Id: displaycard_opengl_win32.h,v 1.4 2001/10/14 20:38:51 japj Exp $
 
 	------------------------------------------------------------------------
 	ClanLib, the platform independent game SDK.
@@ -40,12 +40,13 @@ public:
 	// -------------------------
 
 	virtual void flip_display(bool sync=false);
-	virtual void set_videomode(int width, int height, int bpp, bool fullscreen, bool allow_resize);
+	virtual void put_display(const class CL_Rect &rect);
+	virtual void set_videomode(int width, int height, int bpp, bool fullscreen, bool allow_resize, bool video_memory);
 
 	virtual std::string get_name() { return "opengl"; }
 	
 private:
-	friend CL_OpenGL_Initializer;
+	friend class CL_OpenGL_Initializer;
 //	bool initialized;
 
 	static HGLRC context;
